.. ssbkonf documentation master file, created by
   sphinx-quickstart on Mon Sep  4 12:38:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
.. toctree::
   :maxdepth: 2
   :caption: Contents:


